@@ -151,6 +151,11 @@
 {% endmacro %}
 
 
+{% macro trino__get_batch_size() %}
+  {{ return(1000) }}
+{% endmacro %}
+
+
 {% macro trino__list_schemas(database) -%}
   {% call statement('list_schemas', fetch_result=True, auto_begin=False) %}
     select distinct schema_name
@@ -169,3 +174,7 @@
   {%- endcall %}
   {{ return(load_result('check_schema_exists').table) }}
 {% endmacro %}
+
+{% macro trino__current_timestamp() -%}
+    CURRENT_TIMESTAMP
+{%- endmacro %}
